@@ -1,14 +1,17 @@
-from typing import Any, Dict, List, Tuple, Type
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Type
 
 import duckdb
 from sqlalchemy import pool
 from sqlalchemy import types as sqltypes
 from sqlalchemy import util
-from sqlalchemy.dialects.postgresql import dialect as postgres_dialect
-from sqlalchemy.dialects.postgresql.base import PGExecutionContext, PGInspector
+from sqlalchemy.dialects.postgresql.base import PGInspector
+from sqlalchemy.dialects.postgresql.psycopg2 import PGDialect_psycopg2
 from sqlalchemy.engine.url import URL
 
-__version__ = "0.3.4"
+__version__ = "0.4.0"
+
+if TYPE_CHECKING:
+    from sqlalchemy.base import Connection
 
 
 class DBAPI:
@@ -37,12 +40,14 @@ class DuckDBInspector(PGInspector):
 class ConnectionWrapper:
     c: duckdb.DuckDBPyConnection
     notices: List[str]
+    autocommit = None  # duckdb doesn't support setting autocommit
+    closed = False
 
     def __init__(self, c: duckdb.DuckDBPyConnection) -> None:
         self.c = c
         self.notices = list()
 
-    def cursor(self) -> "ConnectionWrapper":
+    def cursor(self) -> "Connection":
         return self
 
     def fetchmany(self, size: int = None) -> List:
@@ -62,7 +67,7 @@ class ConnectionWrapper:
         return getattr(self.c, name)
 
     @property
-    def connection(self) -> "ConnectionWrapper":
+    def connection(self) -> "Connection":
         return self
 
     def close(self) -> None:
@@ -108,18 +113,18 @@ class DuckDBEngineWarning(Warning):
     pass
 
 
-class Dialect(postgres_dialect):
+class Dialect(PGDialect_psycopg2):
     name = "duckdb"
     driver = "duckdb_engine"
     _has_events = False
-    identifier_preparer = None
     supports_statement_cache = False
     supports_comments = False
     supports_sane_rowcount = False
+    supports_comments = False
     inspector = DuckDBInspector
     # colspecs TODO: remap types to duckdb types
     colspecs = util.update_copy(
-        postgres_dialect.colspecs,
+        PGDialect_psycopg2.colspecs,
         {
             # the psycopg2 driver registers a _PGNumeric with custom logic for
             # postgres type_codes (such as 701 for float) that duckdb doesn't have
@@ -132,23 +137,12 @@ class Dialect(postgres_dialect):
         kwargs["use_native_hstore"] = False
         super().__init__(*args, **kwargs)
 
-    def connect(
-        self, database: str, read_only: bool = False, config: Dict = None
-    ) -> ConnectionWrapper:
-        return ConnectionWrapper(duckdb.connect(database, read_only, config or {}))
+    def connect(self, *cargs: Any, **cparams: Any) -> "Connection":
+        return ConnectionWrapper(duckdb.connect(*cargs, **cparams))
 
     def on_connect(self) -> None:
         pass
 
-    def do_execute(
-        self,
-        cursor: ConnectionWrapper,
-        statement: str,
-        parameters: Any,
-        context: PGExecutionContext,
-    ) -> None:
-        cursor.execute(statement, parameters, context)
-
     @classmethod
     def get_pool_class(cls, url: URL) -> Type[pool.Pool]:
         if url.database == ":memory:":
@@ -156,37 +150,17 @@ class Dialect(postgres_dialect):
         else:
             return pool.QueuePool
 
-    def do_executemany(
-        self,
-        cursor: ConnectionWrapper,
-        statement: str,
-        parameters: List[Any],
-        context: PGExecutionContext = None,
-    ) -> None:
-        cursor.executemany(statement, parameters, context)
-
     @staticmethod
     def dbapi() -> Type[DBAPI]:
         return DBAPI
 
-    def create_connect_args(self, u: URL) -> Tuple[Tuple, Dict]:
-        if hasattr(u, "render_as_string"):
-            # Compatible with SQLAlchemy >= 1.4
-            string_representation = u.render_as_string(hide_password=False)  # type: ignore
-        else:
-            # Compatible with SQLAlchemy < 1.4
-            string_representation = u.__to_string__(hide_password=False)
-        return (), {"database": string_representation.split("///")[1]}
-
-    def _get_server_version_info(
-        self, connection: ConnectionWrapper
-    ) -> Tuple[int, int]:
+    def _get_server_version_info(self, connection: "Connection") -> Tuple[int, int]:
         return (8, 0)
 
-    def get_default_isolation_level(self, connection: ConnectionWrapper) -> None:
+    def get_default_isolation_level(self, connection: "Connection") -> None:
         raise NotImplementedError()
 
-    def do_rollback(self, connection: ConnectionWrapper) -> None:
+    def do_rollback(self, connection: "Connection") -> None:
         try:
             super().do_rollback(connection)
         except RuntimeError as e:
@@ -196,16 +170,16 @@ class Dialect(postgres_dialect):
             ):
                 raise e
 
-    def do_begin(self, connection: ConnectionWrapper) -> None:
+    def do_begin(self, connection: "Connection") -> None:
         connection.execute("begin")
 
-    @classmethod
-    def get_dialect_cls(cls, u: str) -> Type["Dialect"]:
-        return cls
-
     def get_view_names(
-        self, connection: ConnectionWrapper, schema: str = None, **kwargs: Any
-    ) -> List[str]:
+        self,
+        connection: Any,
+        schema: Optional[Any] = ...,
+        include: Any = ...,
+        **kw: Any
+    ) -> Any:
         s = "SELECT name FROM sqlite_master WHERE type='view' ORDER BY name"
         rs = connection.exec_driver_sql(s)
 
